Re-exports
pub use collections::PersistentArrayMap;pub use collections::PersistentHashMap;pub use collections::PersistentHashSet;pub use collections::PersistentList;pub use collections::PersistentQueue;pub use collections::PersistentVector;pub use collections::SortedMap;pub use collections::SortedSet;pub use error::ExceptionInfo;pub use error::ValueError;pub use error::ValueResult;pub use hash::ClojureHash;pub use intern::intern_keyword;pub use intern::intern_symbol;pub use jit_hooks::set_var_rebind_hook;pub use keyword::Keyword;pub use native_object::NativeObject;pub use native_object::NativeObjectBox;pub use native_object::gc_native_object;pub use resource::Resource;pub use resource::ResourceHandle;pub use shared::PromoteError;pub use shared::demote;pub use shared::promote;pub use symbol::Symbol;pub use type_hint::TypeHint;pub use types::Agent;pub use types::Arity;pub use types::Atom;pub use types::BoundFn;pub use types::CljxCons;pub use types::CljxFn;pub use types::CljxFnArity;pub use types::CljxFuture;pub use types::CljxPromise;pub use types::Delay;pub use types::DelayState;pub use types::FutureState;pub use types::LazySeq;pub use types::MultiFn;pub use types::Namespace;pub use types::NativeFn;pub use types::NativeFnFunc;pub use types::NativeFnPtr;pub use types::Protocol;pub use types::ProtocolFn;pub use types::ProtocolMethod;pub use types::Thunk;pub use types::Var;pub use types::Volatile;pub use types::bump_protocol_generation;pub use types::protocol_generation;pub use value::MapValue;pub use value::ObjectArray;pub use value::SetValue;pub use value::TypeInstance;pub use value::Value;
Modules
- clone
- Structured-clone boundary between isolates (Phase B2).
- collections
- error
- hash
- intern
- Global keyword and symbol intern tables (Phase B3).
- jit_
hooks - Cross-layer hooks upper tiers install into the value layer.
- keyword
- native_
object - The
NativeObjecttrait for opaque Rust structs exposed as Clojure values. - publish
- Heap promotion of region-allocated values at publish boundaries (Phase 10.5 — the safety net that lets bump regions coexist with the tracing GC).
- regex
- Regular expressions: the engine wrapper behind
Value::Pattern, plus the statefulMatcherthatre-find/re-matches/re-seqdrive. - resource
- The
Resourcetrait for I/O handles and other closeable resources. - shared
- Cross-isolate shared mutable state:
SharedValue,SharedAtom(Phase B3). - symbol
- type_
hint - Primitive type hints (
^long,^double,^longs, …). - types
- Stub types for Phase 4/7 that are referenced by the Value enum.
- value