SerializedValue

Enum SerializedValue 

pub enum SerializedValue {
Show 37 variants Nil, Bool(bool), Long(i64), Double(f64), BigInt(BigInt), BigDecimal(BigDecimal), Ratio(Ratio<BigInt>), Char(char), Str(String), Uuid(u128), Pattern(String), Symbol { namespace: Option<Arc<str>>, name: Arc<str>, version: Option<Arc<str>>, }, Keyword { namespace: Option<Arc<str>>, name: Arc<str>, }, List(Vec<SerializedValue>), Vector(Vec<SerializedValue>), ArrayMap(Vec<(SerializedValue, SerializedValue)>), HashMap(Vec<(SerializedValue, SerializedValue)>), SortedMap(Vec<(SerializedValue, SerializedValue)>), HashSet(Vec<SerializedValue>), SortedSet(Vec<SerializedValue>), Queue(Vec<SerializedValue>), Cons { head: Box<SerializedValue>, tail: Box<SerializedValue>, }, TypeInstance { type_tag: Arc<str>, fields: Vec<(SerializedValue, SerializedValue)>, }, Error(Box<SerializedError>), BooleanArray(Vec<bool>), ByteArray(Vec<i8>), ShortArray(Vec<i16>), IntArray(Vec<i32>), LongArray(Vec<i64>), FloatArray(Vec<f32>), DoubleArray(Vec<f64>), CharArray(Vec<char>), ObjectArray(Vec<SerializedValue>), WithMeta { value: Box<SerializedValue>, meta: Box<SerializedValue>, }, Reduced(Box<SerializedValue>), SharedAtom(Arc<SharedAtom>), ByteBlob(Arc<[u8]>),
}
Send + Sync intermediate form produced by serialize and consumed by deserialize. All heap data is owned (no GcPtr), so it is safe to move across thread boundaries.

Variants



Nil



Bool(bool)



Long(i64)



Double(f64)



BigInt(BigInt)



BigDecimal(BigDecimal)



Ratio(Ratio<BigInt>)



Char(char)



Str(String)



Uuid(u128)



Pattern(String)

Regex stored as source string; recompiled on deserialize.



Symbol

Fields

namespace: Option<Arc<str>>
name: Arc<str>
version: Option<Arc<str>>


Keyword

Fields

namespace: Option<Arc<str>>
name: Arc<str>


List(Vec<SerializedValue>)



Vector(Vec<SerializedValue>)



ArrayMap(Vec<(SerializedValue, SerializedValue)>)



HashMap(Vec<(SerializedValue, SerializedValue)>)



SortedMap(Vec<(SerializedValue, SerializedValue)>)



HashSet(Vec<SerializedValue>)



SortedSet(Vec<SerializedValue>)



Queue(Vec<SerializedValue>)



Cons



TypeInstance

Fields

type_tag: Arc<str>


Error(Box<SerializedError>)



BooleanArray(Vec<bool>)



ByteArray(Vec<i8>)



ShortArray(Vec<i16>)



IntArray(Vec<i32>)



LongArray(Vec<i64>)



FloatArray(Vec<f32>)



DoubleArray(Vec<f64>)



CharArray(Vec<char>)



ObjectArray(Vec<SerializedValue>)



WithMeta



Reduced(Box<SerializedValue>)



SharedAtom(Arc<SharedAtom>)

SharedAtom is inherently cross-isolate; the Arc is simply cloned so both isolates share the same underlying ArcSwap cell.



ByteBlob(Arc<[u8]>)

ByteBlob is an immutable refcounted buffer; clone the Arc.