pub struct PersistentVector { /* private fields */ }Expand description
An immutable persistent vector backed by rpds::Vector.
Implementations
Sourceimpl PersistentVector
impl PersistentVector
pub fn empty() -> Self
pub fn from_vector(vector: VectorSync<Value>) -> Self
pub fn count(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn nth(&self, idx: usize) -> Option<&Value>
pub fn nth(&self, idx: usize) -> Option<&Value>
Return the element at idx, or None if out of bounds.
Sourcepub fn assoc_nth(&self, idx: usize, val: Value) -> Option<Self>
pub fn assoc_nth(&self, idx: usize, val: Value) -> Option<Self>
Return a new vector with element idx replaced, or appended if idx == len.
pub fn inner(&self) -> &VectorSync<Value>